import { ChartD3Service } from '../../services/chart.d3.service';
export class Axis {
    constructor() {
        /**
         * Flags the axis as either the `"x"` or `"y"` axis.
         * Default is x.
         */
        this.dimension = 'x';
        /**
         * Is the axis visible
         */
        this.show = true;
        /**
         * If true will show the hashes in the axis (x only)
         */
        this.ticks = true;
    }
    componentDidLoad() {
        const axisConfig = {
            showAxis: this.show,
            showTicks: this.ticks,
            formattingOptions: {
                locale: this.locale || 'en-US',
                language: this.language || 'en',
                currency: this.currency || 'USD'
            }
        };
        if (this.type) {
            axisConfig.labelType = this.type;
        }
        this.anjAxisDidLoad.emit(axisConfig);
    }
    /** @internal */
    async init(svg, dims, data, axisConfigs, minMax, primarySeries, y) {
        if (this.dimension === 'x') {
            return ChartD3Service.addXAxis(svg, dims, data, axisConfigs, minMax, primarySeries, y);
        }
        else {
            return ChartD3Service.addYAxis(svg, dims, data, axisConfigs, minMax);
        }
    }
    static get is() { return "anj-axis"; }
    static get properties() { return {
        "currency": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "If the type is currency, the currency to use"
            },
            "attribute": "currency",
            "reflect": false
        },
        "dimension": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "AxisDimension",
                "resolved": "\"x\" | \"y\"",
                "references": {
                    "AxisDimension": {
                        "location": "import",
                        "path": "../../types/types"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Flags the axis as either the `\"x\"` or `\"y\"` axis.\nDefault is x."
            },
            "attribute": "dimension",
            "reflect": true,
            "defaultValue": "'x'"
        },
        "language": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "TODO: these probably shouldn't be here"
            },
            "attribute": "language",
            "reflect": false
        },
        "locale": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "string",
                "resolved": "string",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": ""
            },
            "attribute": "locale",
            "reflect": false
        },
        "type": {
            "type": "string",
            "mutable": false,
            "complexType": {
                "original": "FormatType",
                "resolved": "\"currency\" | \"date\" | \"number\" | \"percent\" | \"string\"",
                "references": {
                    "FormatType": {
                        "location": "import",
                        "path": "../../types/types"
                    }
                }
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "The data type of the axis.\nOptions are: 'date' | 'number' | 'string' | 'percent' | 'currency';"
            },
            "attribute": "type",
            "reflect": false
        },
        "show": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "Is the axis visible"
            },
            "attribute": "show",
            "reflect": false,
            "defaultValue": "true"
        },
        "ticks": {
            "type": "boolean",
            "mutable": false,
            "complexType": {
                "original": "boolean",
                "resolved": "boolean",
                "references": {}
            },
            "required": false,
            "optional": false,
            "docs": {
                "tags": [],
                "text": "If true will show the hashes in the axis (x only)"
            },
            "attribute": "ticks",
            "reflect": false,
            "defaultValue": "true"
        }
    }; }
    static get events() { return [{
            "method": "anjAxisDidLoad",
            "name": "anjAxisDidLoad",
            "bubbles": true,
            "cancelable": true,
            "composed": true,
            "docs": {
                "tags": [],
                "text": "Emitted when the axis loads"
            },
            "complexType": {
                "original": "AxisConfig",
                "resolved": "AxisConfig",
                "references": {
                    "AxisConfig": {
                        "location": "import",
                        "path": "../../types/types"
                    }
                }
            }
        }]; }
    static get methods() { return {
        "init": {
            "complexType": {
                "signature": "(svg: any, dims: Dims, data: CoordinateData[], axisConfigs: AxisConfigs, minMax: any, primarySeries?: any, y?: any) => Promise<any>",
                "parameters": [{
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }, {
                        "tags": [],
                        "text": ""
                    }],
                "references": {
                    "Promise": {
                        "location": "global"
                    },
                    "Dims": {
                        "location": "import",
                        "path": "../../types/types"
                    },
                    "CoordinateData": {
                        "location": "import",
                        "path": "../../types/types"
                    },
                    "AxisConfigs": {
                        "location": "import",
                        "path": "../../types/types"
                    }
                },
                "return": "Promise<any>"
            },
            "docs": {
                "text": "",
                "tags": [{
                        "name": "internal",
                        "text": undefined
                    }]
            }
        }
    }; }
}
