import { h } from "@stencil/core";
import { SeriesStyle } from '../../types/types';
import { ChartDataService } from '../../services/chart.data.service';
export class PopoverContentMulti {
    constructor() {
        this.chartListener = ({ detail }) => this.onDataHover(detail);
    }
    connectedCallback() {
        this.chart = this.element.closest('anj-chart');
        if (this.chart) {
            this.chart.addEventListener('anjHover', this.chartListener);
        }
    }
    onDataHover(newValue) {
        if (newValue.seriesStyle !== SeriesStyle.Multi) {
            return;
        }
        if (newValue.axisConfigs.x.labelType === 'date') {
            this.period = ChartDataService.calculateInterval(newValue.data[0]);
        }
        this.displays = newValue.data
            .map((d, i) => {
            const x = d[newValue.activeIndex].x;
            const y = d[newValue.activeIndex].y;
            this.xDisplayValue = ChartDataService.xFormatter(this.period, newValue.axisConfigs.x, x);
            return {
                color: newValue.seriesMeta[newValue.seriesIndex || i].color,
                name: newValue.seriesMeta[newValue.seriesIndex || i].name,
                x,
                y,
                yDisplayValue: ChartDataService.yFormatter(newValue.axisConfigs.y, y)
            };
        });
    }
    getStyle(color) {
        return {
            'background-color': color
        };
    }
    render() {
        return (this.displays) ? [
            h("div", null,
                h("div", null, this.xDisplayValue),
                h("table", { class: "anj-metric-wrapper" }, this.displays.map((disp) => h("tr", null,
                    h("td", null,
                        h("span", { class: "anj-legend-color", style: this.getStyle(disp.color) })),
                    h("td", { class: "anj-label" }, disp.name),
                    h("td", { class: "anj-value" }, disp.yDisplayValue)))))
        ] : undefined;
    }
    static get is() { return "anj-popover-content-multi"; }
    static get originalStyleUrls() { return {
        "$": ["popover-content-multi.scss"]
    }; }
    static get styleUrls() { return {
        "$": ["popover-content-multi.css"]
    }; }
    static get states() { return {
        "displays": {},
        "xDisplayValue": {}
    }; }
    static get elementRef() { return "element"; }
}
